@@ -1,7 +1,7 @@
 package Dist::Zilla::PluginBundle::DROLSKY;
-# git description: v0.20-6-g043d9d2
+# git description: v0.21-5-g5211796
 
-$Dist::Zilla::PluginBundle::DROLSKY::VERSION = '0.21';
+$Dist::Zilla::PluginBundle::DROLSKY::VERSION = '0.22';
 use v5.10;
 
 use strict;
@@ -17,7 +17,7 @@ use Pod::Weaver::Section::Contributors;
 use Dist::Zilla::Plugin::Authority;
 use Dist::Zilla::Plugin::AutoPrereqs;
 use Dist::Zilla::Plugin::CheckPrereqsIndexed;
-use Dist::Zilla::Plugin::CopyReadmeFromBuild;
+use Dist::Zilla::Plugin::CPANFile;
 use Dist::Zilla::Plugin::DROLSKY::Contributors;
 use Dist::Zilla::Plugin::DROLSKY::License;
 use Dist::Zilla::Plugin::Git::Check;
@@ -161,7 +161,11 @@ sub mvp_multivalue_args {
 sub _build_plugins {
     my $self = shift;
 
-    my %exclude_filename = ( 'README.md' => 1 );
+    my %exclude_filename = map { $_ => 1 } qw(
+        cpanfile
+        LICENSE
+        README.md
+    );
     my @exclude_match;
     for my $exclude ( @{ $self->exclude_files() } ) {
         if ( $exclude =~ m{^[\w\-\./]+$} ) {
@@ -172,7 +176,14 @@ sub _build_plugins {
         }
     }
 
-    my @allow_dirty = qw( Changes CONTRIBUTING.md README.md );
+    my @allow_dirty = qw(
+        Changes
+        cpanfile
+        CONTRIBUTING.md
+        LICENSE
+        README.md
+    );
+
     my @plugins     = (
         $self->make_tool(),
         [
@@ -187,6 +198,11 @@ sub _build_plugins {
                 : ()
             },
         ],
+        [
+            CopyFilesFromBuild => {
+                copy => [qw( cpanfile LICENSE )],
+            },
+        ],
         [
             GatherDir => {
                 exclude_filename => [ keys %exclude_filename ],
@@ -229,6 +245,10 @@ sub _build_plugins {
                 phase             => 'release',
                 check_all_plugins => 1,
                 check_all_prereqs => 1,
+                skip              => [
+                    'Dist::Zilla::Plugin::DROLSKY::Contributors',
+                    'Dist::Zilla::Plugin::DROLSKY::License',
+                ],
             }
         ],
         [
@@ -281,7 +301,7 @@ sub _build_plugins {
             ),
         qw(
             CheckPrereqsIndexed
-            CopyReadmeFromBuild
+            CPANFile
             DROLSKY::Contributors
             DROLSKY::License
             Git::CheckFor::CorrectBranch
@@ -400,7 +420,7 @@ Dist::Zilla::PluginBundle::DROLSKY - DROLSKY's plugin bundle
 
 =head1 VERSION
 
-version 0.21
+version 0.22
 
 =for Pod::Coverage .*
 
